%define anolis_release 3

# Default to no static libraries
%{!?with_static: %global with_static 0}
%bcond_with bundled_libpfm
%{!?with_rdma: %global with_rdma 1}
%{!?with_pcp: %global with_pcp 0}
%bcond_with abi

Summary:  Performance Application Programming Interface
Name:     papi
Version: 7.1.0
Release:  %{anolis_release}%{?dist}
License: BSD-3-Clause
URL:      http://icl.cs.utk.edu/papi/
Source0:  http://icl.cs.utk.edu/projects/papi/downloads/%{name}-%{version}.tar.gz

Patch1: papi-python3.patch
Patch2: papi-nostatic.patch
Patch3: papi-libsde.patch


Patch1001: 1001-add-loongarch64-support-for-papi.patch
Patch1002: papi-7.0.1-support-sw.patch
Patch1003: add-riscv64-support-for-papi.patch

Requires: papi-libs = %{version}-%{release}
BuildRequires: make
BuildRequires: autoconf
BuildRequires: doxygen
BuildRequires: ncurses-devel
BuildRequires: gcc-gfortran
BuildRequires: kernel-headers >= 2.6.32
BuildRequires: chrpath
BuildRequires: lm_sensors-devel
%if %{without bundled_libpfm}
BuildRequires: libpfm-devel >= 4.13.0-1
%if %{with_static}
BuildRequires: libpfm-static >= 4.6.0-1
%endif
%endif
# Following required for net component
BuildRequires: net-tools
%if %{with_rdma}
# Following required for inifiband component
BuildRequires: rdma-core-devel
#BuildRequires: infiniband-diags-devel
%endif
%if %{with_pcp}
BuildRequires: pcp-libs-devel
%endif
BuildRequires: perl-generators

%description
PAPI provides a programmer interface to monitor the performance of
running programs.

%package libs
License: BSD-3-Clause
Summary: Libraries for PAPI clients
%description libs
This package contains the run-time libraries for any application that wishes
to use PAPI.

%package devel
License: BSD-3-Clause
Summary: Header files for the compiling programs with PAPI
Requires: papi = %{version}-%{release}
Requires: papi-libs = %{version}-%{release}
Requires: pkgconfig
%description devel
PAPI-devel includes the C header files that specify the PAPI user-space
libraries and interfaces. This is required for rebuilding any program
that uses PAPI.

%package testsuite
License: BSD-3-Clause
Summary: Set of tests for checking PAPI functionality
Requires: papi = %{version}-%{release}
Requires: papi-libs = %{version}-%{release}
%description testsuite
PAPI-testsuite includes compiled versions of papi tests to ensure
that PAPI functions on particular hardware.

%if %{with_static}
%package static
License: BSD-3-Clause
Summary: Static libraries for the compiling programs with PAPI
Requires: papi = %{version}-%{release}
%description static
PAPI-static includes the static versions of the library files for
the PAPI user-space libraries and interfaces.
%endif

%package        doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%setup -q
%patch1 -p1 -b .python3
%patch2 -p1
%patch3 -p1 -b .flags
%patch1001 -p1
%patch1002 -p1
%patch1003 -p1

%build

%if %{without bundled_libpfm}
# Build our own copy of libpfm.
%global libpfm_config --with-pfm-incdir=%{_includedir} --with-pfm-libdir=%{_libdir}
%endif

%if %{with_static}
%global static_lib_config --with-static-lib=yes
%else
%global static_lib_config --with-static-lib=no
%endif

# set up environment variable for the various components
# cuda
# host_micpower
%if  %{with_rdma}
  export PAPI_INFINIBAND_UMAD_ROOT=/usr
%endif
# lmsensors
export PAPI_LMSENSORS_ROOT=/usr
#pushd vmware; ./configure; popd
%if %{with_pcp}
%global pcp_enable pcp
export PAPI_PCP_ROOT=/usr
%endif

cd src
autoconf
%configure --with-perf-events \
%{?libpfm_config} \
%{?static_lib_config} \
--with-shared-lib=yes --with-shlib-tools \
--with-components="appio coretemp example infiniband lmsensors lustre micpower mx net %{?pcp_enable} rapl stealtime"
# implicit enabled components: perf_event perf_event_uncore
#components currently left out because of build configure/build issues
# --with-components="bgpm coretemp_freebsd cuda host_micpower nvml vmware"

#DBG workaround to make sure libpfm just uses the normal CFLAGS
DBG="" make %{?_smp_mflags}

#generate updated versions of the documentation
#DBG workaround to make sure libpfm just uses the normal CFLAGS
pushd ../doc
DBG="" make
DBG="" make install
popd

%install
rm -rf $RPM_BUILD_ROOT
cd src
make DESTDIR=$RPM_BUILD_ROOT LDCONFIG=/bin/true install-all

# Scrub the rpath/runpath from all the binaries.
find %{buildroot} -type f -executable ! -iname "*.py" ! -iname "*.sh" | xargs chrpath --delete

%if %{with abi}
%generate_compatibility_deps
%endif

%files
%{_bindir}/*
%dir /usr/share/papi
/usr/share/papi/papi_events.csv
%doc LICENSE.txt
%doc %{_mandir}/man1/*
%if %{with abi}
%{abidir}/papi_avail-option.list
%{abidir}/papi_clockres-option.list
%{abidir}/papi_command_line-option.list
%{abidir}/papi_component_avail-option.list
%{abidir}/papi_error_codes-option.list
%{abidir}/papi_hardware_avail-option.list
%{abidir}/papi_hl_output_writer.py-option.list
%{abidir}/papi_mem_info-option.list
%{abidir}/papi_multiplex_cost-option.list
%{abidir}/papi_version-option.list
%{abidir}/papi_xml_event_info-option.list
%endif

%files libs
%{_libdir}/*.so.*
%if %{with abi}
%doc INSTALL.txt README.md LICENSE.txt RELEASENOTES.txt
%dir %{abidir}
%{abidir}/libpapi.dump
%{abidir}/libsde.dump
%endif

%files devel
%{_includedir}/*.h
%{_includedir}/*.hpp
%if %{with bundled_libpfm}
%{_includedir}/perfmon/*.h
%endif
%{_libdir}/*.so
%{_libdir}/pkgconfig/papi*.pc
%doc %{_mandir}/man3/*

%files testsuite
/usr/share/papi/run_tests*
/usr/share/papi/ctests
/usr/share/papi/ftests
/usr/share/papi/validation_tests
/usr/share/papi/components
/usr/share/papi/testlib

%if %{with_static}
%files static
%{_libdir}/*.a
%endif

%files doc
%doc INSTALL.txt README.md RELEASENOTES.txt

%changelog
* Wed May 7 2025 Yihao Yan <yan.yihao@zte.com.cn> - 7.1.0-3
- add support for riscv64

* Wed Apr 2 2025 chaodong <chaodong@nfschina.com> - 7.0.1-2
- support sw, papi-7.0.1-support-sw.patch

* Wed Mar 19 2025 Xiaoping Liu <lxp01404969@alibaba-inc.com> - 7.1.0-1
- update to 7.1.0 from 7.0.1
- Migrated to SPDX license
- Ensure sde library built with proper flags
  [Patches cherry-pick from c10s. Original changelog:
  - Ensure sde library built with proper flags. ( 7.1.0-4 )]

* Tue Oct 10 2023 Wenlong Zhang<zhangwenlong@loongson.cn> - 7.0.1-2
- add loongarch64 support for papi
- disable generate_compatibility_deps to fix build timeout

* Mon Mar 27 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 7.0.1-1
- Init from upstream
